@@ -1,6 +1,8 @@
 package Filter::sh;
  
 use Carp ;
+use strict ;
+use warnings ;
 use vars qw($VERSION) ;
 $VERSION = "1.01" ;
 
